# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['lolaaur']

package_data = \
{'': ['*']}

install_requires = \
['click>=8.0.1,<9.0.0', 'requests>=2.25.1,<3.0.0']

entry_points = \
{'console_scripts': ['lola = lolaaur.lolacli:main']}

setup_kwargs = {
    'name': 'lolaaur',
    'version': '0.1.3',
    'description': 'An AUR connected package manager with wide variety of packages',
    'long_description': "# Lola\n### `lolaAUR` : A simple CLI package manager for Arch/Arch Based Linux \n\n[![Downloads](https://static.pepy.tech/personalized-badge/lolaaur?period=total&units=abbreviation&left_color=black&right_color=blue&left_text=Downloads)](https://pepy.tech/project/lolaaur)\n\n**lola is made for linux users who want to download software fast and easy!**\n\nNow many will ask, Why use lola when we have those software managers?\n\nWell, lola is a Command Line Interface and is used inside the terminal. And as we know, terminal downloads are way more faster than the software managers. While many softwares can be downloaded with a single `sudo apt install`, most common ones need some more commands.\n\nSo `lola` is here to make your life way more easier while installing software! This project targets both advanced and beginner users, because who doesn't like speedy and quicky stuff?\n\n#### Dependencies\n+ `click` \n\n### Built with\n+ `Python 3.8.5` \n\n![python](https://raw.githubusercontent.com/MikeCodesDotNET/ColoredBadges/master/svg/dev/languages/python.svg)\n\n\n## Installation\n\n#### Method 1 (Recommended):\n\nIf you dont have python3 and pip installed on your system, or are not that much of PYTHON CODER, use this method\n\n- Install wget with `sudo pacman -S wget`\n\n- In your terminal-\n\n```bash\ncd ~/Downloads;wget https://raw.githubusercontent.com/arghyagod-coder/lola/master/lolacli/install.sh; sudo bash install.sh\n```\n\n- Now `lola` is ready to work!\n\n#### Method 2\n\nIf you have python and pip installed in your computer, execute the following\n\n```bash\npip3 install lolacli\n```\n\nBut, there are some dependencies that you will need if you go for method 2. They are the following:\n\n- git (`sudo pacman -S git`)\n- yay (`sudo pacman -S yay`)\n\n## Supported Platforms:\n\n+ Operating System = Linux64 \n\n![lin](https://raw.githubusercontent.com/MikeCodesDotNET/ColoredBadges/master/svg/dev/tools/bash.svg)\n    \n  - Arch Linux and Derivatives like Manjaro, Garuda etc\n\n### Guide\n\n- The help command\n\n```bash\n>lola --help\n\n\n  I am Lola! Your assistant who can help you setup your Linux in an easy way!\n  You can know more about me in https://github.com/arghyagod-coder/lolaaur.\n\n  I can help you install apps through terminal, and you need to know almost\n  nothing about the terminal to do so! Just simple prompts will be enough\n\nOptions:\n  --version  Show the version and exit.\n  --help     Show this message and exit.\n\nCommands:\n  list        Check the list of supported apps!\n  install     Install an app\n\n```\n\n- Check some supported apps of AUR by using the `lola list` command. This list only gives names of a few packages, but every package in AUR repos can be installed via lolaAUR\n\n```bash\n> lola list\n\n\nanaconda ------------- Anaconda- Powerful Tool for DS, DL and ML learners\natom-editor ---------- Atom Code Editor \naudacious ------------ Audacious Music Player\naudacity ------------- Professional Audio Edition Software\nblender-3.0 -------------- Open Source 3D Creation Suite\nbrave ---------------- Brave Browser- Fast, Light and Secure\nbrave-beta ----------- Brave Browser BETA- Regular updates and Bug Fixes\nbrave-nightly -------- Brave Nightly- Nightly Updates and Bug Fixes\ncalibre -------------- Free E-Book Suite\ncheese --------------- Camera App for Linux\nchrome --------------- Google Chrome Browser, the No.1 Browser in market\nchromium ------------- Chromium Browser- A Light Browser like Chrome by GOOGLE\nclang90 -------------- CLang Compiler for C\ncodeblocks-svn ------- Code::Blocks editor- Fast and Powerful\ncrystal -------------- Crystal language support\ndesmume -------------- DesMume Emulator for NDS and GB Games\ndiscord -------------- Discord Client in Linux\ndosbox -------------- DOS-BOX Emulator\ndropbox -------------- Cloud Storage Client\nmicrosoft-edge-dev-bin - MS Edge for Linux- Regular Updates \nemacs ---------------- Featureful Text Editor\n...\n```\n\n- Install an app through lola with the `lola install <appname>` command\n\n```bash\n> lola install etcher\n \n[sudo] password for user: \nresolving dependencies...\nlooking for conflicting packages...\n\nPackages (1) etcher-1.5.120-1\n\nTotal Installed Size:  36.26 MiB\n\n:: Proceed with installation? [Y/n] y\n(1/1) checking keys in keyring                                                    [##############################################] 100%\n(1/1) checking package integrity                                                  [##############################################] 100%\n(1/1) loading package files                                                       [##############################################] 100%\n(1/1) checking for file conflicts                                                 [##############################################] 100%\n(1/1) checking available disk space                                               [##############################################] 100%\n:: Processing package changes...\n(1/1) installing etcher                                                           [##############################################] 100%\nOptional dependencies for etcher\n    libnotify: for notifications [installed]\n:: Running post-transaction hooks...\n(1/3) Arming ConditionNeedsUpdate...\n(2/3) Updating icon theme caches...\n(3/3) Updating the desktop file MIME type cache...\n```\n\n- Search Option\n  - `lola search <appname>` checks the availability of an app in lola.\n  \n```bash\n> lola search vlc\n\nvlc available!\n```\n\n- `lola update` updates lola to the latest version\n  \n- **Fun Feature-** Use `lola hack <computer_name>` to perform a fake hack on any target pc >_<\n\n- `lola info` gives you a brief description of Lola\n\n## Developer Tools\n\n- [Python 3.8.5](https://www.python.org/ftp/python/3.8.5/Python-3.8.5.tar.xz) \n\n![python](https://raw.githubusercontent.com/MikeCodesDotNET/ColoredBadges/master/svg/dev/languages/python.svg)\n\n- [Sublime Text 3](https://www.sublimetext.com/3)\n\n- [Visual Studio Code](https://code.visualstudio.com) \n\n![vscode](https://raw.githubusercontent.com/MikeCodesDotNET/ColoredBadges/master/svg/dev/tools/visualstudio_code.svg)\n\n- [Git](https://git-scm.com/) \n\n![git](https://raw.githubusercontent.com/klaasnicolaas/ColoredBadges/new-badges/svg/dev/tools/git.svg)\n\n- [Python Poetry](https://python-poetry.org/) for package management and publishing\n\n## Release Notes\n\n- **Current Release- 0.1.2 (Initial Release)**\n\n### What's new?\n\n- Connections to AUR repository make lola very powerful\n- By chance, if there's no such repository in AUR, lola attempts to resolve the packages with other managers\n- Better Exception Handling\n- Added few fun features to enhance user experience\n\n#### Developers\n- [Arghya Sarkar](https://github.com/arghyagod-coder)\n\n## License\n\nLicense © 2021-Present Arghya Sarkar\n\nThis repository is licensed under the MIT license. See [LICENSE](https://github.com/arghyagod-coder/lolaaur/master/LICENSE) for details.\n\n## Special Notes\n\n- Contribution is appreciated! Visit the contribution guide in [Contribution Guide](CONTRIBUTING.md)\n- If you don't find an app in the supported app list, file an issue in [the issue page](https://github.com/arghyagod-coder/lolaaur/issues). Issues aren't ignored by the developers\n- Thanks for seeing my project!",
    'author': 'Arghya Sarkar',
    'author_email': 'arghyasarkar.joker@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/arghyagod-coder/lolaaur',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
